translate.convert.po2moz

Package translate :: Package convert :: Module po2moz |
[hide private]
[frames] | no frames]

# Module po2moz

source code

convert Gettext PO localization files to Mozilla .dtd and .properties files

see: http://translate.sourceforge.net/wiki/toolkit/po2moz for examples and usage instructions

Classes | [hide private]
| MozConvertOptionParser

Functions | [hide private]
main(argv=None) | source code

Imports: os, po2dtd, po2prop, prop2mozfunny, xpi, convert